@@ -11,7 +11,7 @@ use strict;
 use warnings;
 
 package Dist::Zilla::Plugin::Git::Tag;
-our $VERSION = '1.093260';
+our $VERSION = '1.093300';
 
 
 # ABSTRACT: tag the new version
@@ -20,21 +20,31 @@ use Git::Wrapper;
 use Moose;
 use MooseX::Has::Sugar;
 use MooseX::Types::Moose qw{ Str };
+use String::Formatter method_stringf => {
+  -as => '_format_tag',
+  codes => {
+    v => sub { $_[0]->version },
+  },
+};
 
 with 'Dist::Zilla::Role::AfterRelease';
 
 
 # -- attributes
 
-has filename => ( ro, isa=>Str, default => 'Changes' );
+has filename   => ( ro, isa=>Str, default => 'Changes' );
+has tag_format => ( ro, isa=>Str, default => 'v%v' );
+
+
+# -- role implementation
 
 sub after_release {
     my $self = shift;
     my $git  = Git::Wrapper->new('.');
 
     # create a tag with the new version
-    my $newver = $self->zilla->version;
-    $git->tag( "v$newver" );
+    my $tag = _format_tag($self->tag_format, $self->zilla);
+    $git->tag( $tag );
 }
 
 1;
@@ -48,7 +58,7 @@ Dist::Zilla::Plugin::Git::Tag - tag the new version
 
 =head1 VERSION
 
-version 1.093260
+version 1.093300
 
 =head1 SYNOPSIS
 
@@ -60,13 +70,16 @@ In your F<dist.ini>:
 =head1 DESCRIPTION
 
 Once the release is done, this plugin will record this fact in git by
-creating a tag named C<v$VERSION>.
+creating a tag.
 
 The plugin accepts the following options:
 
 =over 4
 
-=item * filename - the name of your changelog file. defaults to F<Changes>.
+=item * filename - the name of your changelog file. Defaults to F<Changes>.
+
+=item * tag_format - format of the tag to apply. C<%v> will be
+replaced by the dist version. Defaults to C<v%v>.
 
 =back
 
